==> zio-aws-mediatailor_3-5.17.124.3-sources.jar: zio/aws/mediatailor/model/GetChannelPolicyResponse.scala <==
package zio.aws.mediatailor.model
import zio.aws.mediatailor.model.primitives.__string
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class GetChannelPolicyResponse(policy: Option[__string] = None) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediatailor.model.GetChannelPolicyResponse = {
    import GetChannelPolicyResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediatailor.model.GetChannelPolicyResponse
      .builder()
      .optionallyWith(
        policy.map(value => __string.unwrap(value): java.lang.String)
      )(_.policy)
      .build()
  }
  def asReadOnly: zio.aws.mediatailor.model.GetChannelPolicyResponse.ReadOnly =
    zio.aws.mediatailor.model.GetChannelPolicyResponse.wrap(buildAwsValue())
}
object GetChannelPolicyResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediatailor.model.GetChannelPolicyResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediatailor.model.GetChannelPolicyResponse =
      zio.aws.mediatailor.model
        .GetChannelPolicyResponse(policy.map(value => value))
    def policy: Option[__string]
    def getPolicy: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("policy", policy)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediatailor.model.GetChannelPolicyResponse
  ) extends zio.aws.mediatailor.model.GetChannelPolicyResponse.ReadOnly {
    override val policy: Option[__string] = scala
      .Option(impl.policy())
      .map(value => zio.aws.mediatailor.model.primitives.__string(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediatailor.model.GetChannelPolicyResponse
  ): zio.aws.mediatailor.model.GetChannelPolicyResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-mediatailor_3-5.17.158.3-sources.jar: zio/aws/mediatailor/model/GetChannelPolicyResponse.scala <==
package zio.aws.mediatailor.model
import zio.aws.mediatailor.model.primitives.__string
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class GetChannelPolicyResponse(policy: Option[__string] = None) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediatailor.model.GetChannelPolicyResponse = {
    import GetChannelPolicyResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediatailor.model.GetChannelPolicyResponse
      .builder()
      .optionallyWith(policy.map(value => value: java.lang.String))(_.policy)
      .build()
  }
  def asReadOnly: zio.aws.mediatailor.model.GetChannelPolicyResponse.ReadOnly =
    zio.aws.mediatailor.model.GetChannelPolicyResponse.wrap(buildAwsValue())
}
object GetChannelPolicyResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediatailor.model.GetChannelPolicyResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediatailor.model.GetChannelPolicyResponse =
      zio.aws.mediatailor.model
        .GetChannelPolicyResponse(policy.map(value => value))
    def policy: Option[__string]
    def getPolicy: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("policy", policy)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediatailor.model.GetChannelPolicyResponse
  ) extends zio.aws.mediatailor.model.GetChannelPolicyResponse.ReadOnly {
    override val policy: Option[__string] =
      scala.Option(impl.policy()).map(value => value: __string)
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediatailor.model.GetChannelPolicyResponse
  ): zio.aws.mediatailor.model.GetChannelPolicyResponse.ReadOnly = new Wrapper(
    impl
  )
}
